// -*- C++ -*-
#ifndef MATH_CASESINSET_H
#define MATH_CASESINSET_H

#include "math_gridinset.h"


class MathCasesInset : public MathGridInset {
public:
	///
	explicit MathCasesInset(row_type rows = 1u);
	///
	MathInset * clone() const;
	///
	void metrics(MathMetricsInfo & st) const;
	///
	void draw(MathPainterInfo & pain, int x, int y) const;

	///
	void infoize(std::ostream & os) const;
	///
	void normalize(NormalStream &) const;
	///
	void maplize(MapleStream &) const;
	///
	void write(WriteStream & os) const;
	///
	void validate(LaTeXFeatures & features) const;
};

#endif
